==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridScrollEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDetailDescription } from "./WebGridScrollEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebGridScrollEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridScrollEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridScrollEventArgsDetailDescriptionMetadata.a == null) {
                WebGridScrollEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridScrollEventArgsDetailDescriptionMetadata.c(WebGridScrollEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebGridScrollEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridScrollEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Direction", "String");
            a.item("ScrollPosition", "Number:double");
        }
        static d(a) {
            WebGridScrollEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebGridScrollEventArgsDetail", () => new WebGridScrollEventArgsDetailDescription());
            a.ac("WebGridScrollEventArgsDetail", WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebGridScrollEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridScrollEventArgsDetailDescriptionMetadata, 'WebGridScrollEventArgsDetailDescriptionMetadata');
    WebGridScrollEventArgsDetailDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebGridScrollEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDetailDescription } from "./WebGridScrollEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebGridScrollEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridScrollEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridScrollEventArgsDetailDescriptionMetadata.a == null) {
                WebGridScrollEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridScrollEventArgsDetailDescriptionMetadata.c(WebGridScrollEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebGridScrollEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridScrollEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Direction", "String");
            a.item("Event", "Unknown");
            a.item("ScrollPosition", "Number:double");
        }
        static d(a) {
            WebGridScrollEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebGridScrollEventArgsDetail", () => new WebGridScrollEventArgsDetailDescription());
            a.ad("WebGridScrollEventArgsDetail", WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebGridScrollEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridScrollEventArgsDetailDescriptionMetadata, 'WebGridScrollEventArgsDetailDescriptionMetadata');
    WebGridScrollEventArgsDetailDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDetailDescriptionMetadata;
})();
